@@ -163,6 +163,8 @@ TYPE_MAP = {
         TypeSpec(['.tt', '.tt2', '.ttml'], []),
     'txt':
         TypeSpec(['.txt', '.text'], []),
+    'txtar':
+        TypeSpec(['.txtar'], []),
     'ts':
         TypeSpec(['.ts', '.tsx'], []),
     'typescript':
@@ -175,6 +177,10 @@ TYPE_MAP = {
         TypeSpec(['.vim'], []),
     'vhdl':
         TypeSpec(['.vhd', '.vhdl'], []),
+    'wasm':
+        TypeSpec(['.wat'], []),
+    'wat':
+        TypeSpec(['.wat'], []),
     'withoutext':
         TypeSpec([''], []),
     'xml':
@@ -187,7 +193,8 @@ IGNORED_DIRS = frozenset([
     'blib', '_build', '.bzr', '.cdv', 'cover_db', '__pycache__',
     'CVS', '_darcs', '~.dep', '~.dot', '.git', '.hg', '~.nib',
     '.pc', '~.plst', 'RCS', 'SCCS', '_sgbak', '.svn', '.tox',
-    '.metadata', '.cover', '.Rproj.user', '.Rhistory', 'node_modules'])
+    '.metadata', '.cover', '.Rproj.user', '.Rhistory', 'node_modules',
+    '.ipynb_checkpoints'])
 
 IGNORED_FILE_PATTERNS = frozenset(
     [r'~$', r'#.+#$', r'[._].*\.swp$', r'core\.\d+$'])
